<?php
/**
 * A cache factory
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CacheFactory extends BaseFactory {
	/**
	 * Singleton instance
	 */
	private static $selfInstance = null;

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Singleton getter for this class
	 *
	 * @return	$selfInstance	An instance of this class
	 */
	public final static function getFactory () {
		// Is the instance null?
		if (is_null(self::$selfInstance)) {
			// Set a new one
			self::$selfInstance = new CacheFactory();
		}

		// Return the instance
		return self::$selfInstance;
	}

	/**
	 * Creates a configured cache instance
	 *
	 * @return	$cacheInstance	An instance of the configured cache
	 */
	public function createConfiguredCache () {
		// Read the config entry
		$cacheType = $this->getConfigInstance()->getConfigEntry('cache_class');

		// And get a new instance
		$cacheInstance = ObjectFactory::createObjectByName($cacheType);

		// Return the instance
		return $cacheInstance;
	}
}

// [EOF]
?>
